#! /bin/bash

# Copyright 2016 Midokura SARL
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

source $TOP_DIR/stackrc

# Provide external connectivity

sudo sysctl -w net.ipv4.ip_forward=1
sudo iptables -t nat -A POSTROUTING \
    -s ${FLOATING_RANGE} -o ${PUBLIC_INTERFACE} \
    -j MASQUERADE
