# Copyright 2015 Midokura SARL
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""start neutron-midonet chain

Revision ID: start_neutron_midonet
Revises: None
Create Date: 2014-10-27 13:26:15.053540

"""

# revision identifiers, used by Alembic.
revision = 'start_neutron_midonet'
down_revision = None


def upgrade():
    pass
